/*
Changeable skate colors for Shadow
	by Lach
*/

local FILENAME = "client/shadow/deez.dat"
local MAXSPLITSCREENPLAYERS = 2
local DEFAULTVALUE = string.rep("None\n", MAXSPLITSCREENPLAYERS)

local function valid(mo)
	return mo and mo.valid
end

// return a skincolor based on the name read from the file
local function ReadSkateColor(line)
	local file = io.openlocal(FILENAME)
	
	if not file // no file? use the default
		return 0
	end
	
	while line > 1
		line = $ - 1
		file:read()
	end
	
	local val = R_GetColorByName(file:read())
	
	file:close()
	
	return val or 0
end

// save the skincolor names to the file
local function WriteSkateColor(val, line)
	local n = 0
	local text
	local file = io.openlocal(FILENAME)
	
	if file
		text = file:read("*a")
		file:close()
	else
		text = DEFAULTVALUE
	end
	
	line = $ or 0
	while line > 1
		line = $ - 1
		n = text:find('\n', n + 1)
	end
	
	local fin = text:find('\n', n + 1)
	
	file = io.openlocal(FILENAME, "w+")
	file:write(text:sub(1, n), val and skincolors[val].name or "None", text:sub(fin))
	file:close()
end

// set this player's skatecolor to the given skincolor, and save
local function SetSkateColor(player, n)
	player.shadow_skatecolor = n
	WriteSkateColor(player.shadow_skatecolor, player == secondarydisplayplayer and 2 or 1)
end

local function ChangeSkateColor(player, arg)
	if not arg
		CONS_Printf(splitscreen and consoleplayer or player,
			"Sets the color of Shadow's skate flames. Can be the name or number of a skincolor!"..
			"\nCurrently set to "..(player.shadow_skatecolor and skincolors[player.shadow_skatecolor].name or "Default")..".")
		return
	end
	
	arg = $:upper()
	
	if arg == "DEFAULT"
	or arg == "OFF"
		SetSkateColor(player, 0)
		return
	end
	
	local n = tonumber(arg)
	if n ~= nil
	and n >= 0 and n <= #skincolors
		SetSkateColor(player, n)
		return
	end
	
	local exists, color = pcall(function(name) return _G["SKINCOLOR_"..name] end, arg)
	if exists
		SetSkateColor(player, color)
		return
	end
	
	color = R_GetColorByName(arg)
	if color
		SetSkateColor(player, color)
		return
	end
	
	CONS_Printf(splitscreen and consoleplayer or player,
		"Not a valid color!")
end

COM_AddCommand("skatecolor2", ChangeSkateColor, COM_SPLITSCREEN)
COM_AddCommand("skatecolor", ChangeSkateColor)

local configplayers = {}

addHook("ThinkFrame", do
	for i, player in ipairs({consoleplayer, secondarydisplayplayer})
		if not valid(configplayers[i])
			configplayers[i] = player
			if player.shadow_skatecolor == nil
				player.shadow_skatecolor = ReadSkateColor(i)
			end
		end
	end
end)
			